@@ -14,4 +14,4 @@ class ObjResult:
 
     def __post_init__(self):
         if isinstance(self.obj, LOB):
-            self.obj = self.obj.read()
+            self.obj = self.obj.open().read()
